@@ -14,3 +14,12 @@ class DropboxAuthException(Exception):
         """Initialize exception."""
         super().__init__(status)
         self.status = status
+
+
+class DropboxUnknownException(Exception):
+    """Raised when an unknown Dropbox error occurs."""
+
+    def __init__(self, status):
+        """Initialize exception."""
+        super().__init__(status)
+        self.status = status
